# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import typing_extensions

from ...commons.types.invoice_id import InvoiceId

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class InvoiceUpdate_Set(pydantic.BaseModel):
    type: typing_extensions.Literal["set"]
    value: InvoiceId

    class Config:
        frozen = True
        smart_union = True


class InvoiceUpdate_Remove(pydantic.BaseModel):
    type: typing_extensions.Literal["remove"]

    class Config:
        frozen = True
        smart_union = True


InvoiceUpdate = typing.Union[InvoiceUpdate_Set, InvoiceUpdate_Remove]
